"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sentry_1 = __importDefault(require("probot/lib/apps/sentry"));
const log_request_errors_1 = require("probot/lib/middleware/log-request-errors");
const landing_page_1 = require("./landing-page");
const utils_1 = require("./utils");
const initializeProbot = (applicationFn) => {
    const probot = utils_1.createProbot();
    // Log all unhandled rejections
    process.on("unhandledRejection", probot.errorHandler);
    const application = probot.load(applicationFn);
    probot.load(sentry_1.default);
    probot.server.use(log_request_errors_1.logRequestErrors);
    application
        .route("/")
        .get("/", async (internalRequest, internalResponse) => {
        const name = await utils_1.fetchAppName(application);
        internalResponse.statusCode = 200;
        internalResponse.end(landing_page_1.getLandingPage(name));
    });
    return probot;
};
/**
 * Wrap the given application function as a lambda.
 *
 * @param applicationFn - The function corresponding to this GitHub App.
 */
const toLambda = (applicationFn) => initializeProbot(applicationFn).server;
exports.toLambda = toLambda;
